[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- gchecky: Gchecky provides an abstraction layer between google checkout API and user code.
  - gchecky.controller
  - gchecky.data
  - gchecky.gxml: Gchecky.gxml module provides an abstraction layer when dealing with Google Checkout API services (GC API).
  - gchecky.model: gchecky.model module describes the mapping between Google Checkout API (GC API) XML messages (GC API XML Schema) and data classes.
  - gchecky.test
    - gchecky.test.controller
    - gchecky.test.gxml'
    - gchecky.test.model
  - gchecky.tools: The module provides two classes encoder and decoder that allow to serialize and deserialize python-ish PODs into/from XML.
- unittest: Python unit testing framework, based on Erich Gamma's JUnit and Kent Beck's Smalltalk testing framework.